/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.octo.mtg.plugin;

import com.octo.mtg.plugin.tools.GrailsProject;
import com.octo.mtg.plugin.tools.GrailsServices;
import com.octo.mtg.plugin.tools.MojoServices;
import com.octo.mtg.plugin.tools.PomServices;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;

import java.io.File;

/**
 * Common services for all Mojos using Grails
 *
 * @author <a href="mailto:aheritier@gmail.com">Arnaud HERITIER</a>
 * @version $Id: AbstractGrailsMojo.java 457 2008-05-23 10:57:27Z trygvis $
 */
public abstract class AbstractGrailsMojo extends AbstractMojo {

    /**
     * The directory where is launched the mvn command.
     *
     * @parameter default-value="${basedir}"
     * @required
     */
    protected File basedir;

    /**
     * The Grails environment to use.
     *
     * @parameter expression="${grails.env}"
     */
    protected String env;

    /**
     * The path to GRAILS' HOME.
     *
     * @parameter expression="${grailsHome}"
     * @required
     */
    protected String grailsHome;

    /**
     * @component
     * @readonly
     */
    private GrailsServices grailsServices;

    /**
     * @component
     * @readonly
     */
    protected MojoServices mojoServices;

    /**
     * @component
     * @readonly
     */
    private PomServices pomServices;

    protected File getBasedir() {
        return this.basedir;
    }

    /**
     * Return the Grails descriptor of the project.
     *
     * @return a GrailsProject
     * @throws MojoExecutionException if an error occurs when reading the descriptor.
     */
    public GrailsProject getGrailsDescriptor() throws MojoExecutionException {
        try {
            return grailsServices.readProjectDescriptor();
        } catch (Exception e) {
            throw new MojoExecutionException("Unable to load grails project descriptor.", e);
        }
    }

    protected GrailsServices getGrailsServices() {
        grailsServices.setBasedir(basedir);

        return grailsServices;
    }

    protected PomServices getPomServices() {
        pomServices.setBasedir(basedir);

        return pomServices;
    }
}
