/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.octo.mtg.plugin;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.codehaus.plexus.util.FileUtils;

import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;

/**
 * Copy the POM dependencies in the lib directory of the grails project.
 *
 * @author <a href="mailto:aheritier@gmail.com">Arnaud HERITIER</a>
 * @version $Id: MvnCopyDependenciesMojo.java 456 2008-05-23 09:35:53Z trygvis $
 * @description Copy the POM dependencies in the lib directory of the grails project.
 * @goal copy-dependencies
 * @phase process-resources
 * @requiresDependencyResolution runtime
 * @since 0.3
 */
public class MvnCopyDependenciesMojo extends AbstractGrailsMojo {

    /**
     * List of artifacts to copy to lib/.
     *
     * @parameter expression="${project.runtimeArtifacts}"
     */
    private List runtimeArtifacts;

    public void execute() throws MojoExecutionException, MojoFailureException {
        for (Iterator it = runtimeArtifacts.iterator(); it.hasNext();) {
            Artifact artifact = (Artifact) it.next();

            File source = artifact.getFile();

            File target = new File(new File(getBasedir(), "lib"), source.getName());

            if (target.exists() && target.lastModified() > source.lastModified()) {
                getLog().debug("Target is newer than source, skipping " + artifact.getId() + ".");

                continue;
            }

            try {
                getLog().debug("Copying file from '" + source.getAbsolutePath() + "' to '" + target.getAbsolutePath() + "'.");
                FileUtils.copyFile(source, target);
            } catch (IOException e) {
                throw new MojoExecutionException("Could not copy file from '" + source.getAbsolutePath() + "' to '" + target.getAbsolutePath() + "'.", e);
            }
        }
    }
}
