/*
 * Copyright 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.octo.mtg.plugin;

import com.octo.mtg.plugin.tools.GrailsProject;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import java.io.IOException;

/**
 * Validate consistency between Grails and Maven settings.
 *
 * @author <a href="mailto:aheritier@gmail.com">Arnaud HERITIER</a>
 * @version $Id: MvnValidateMojo.java 458 2008-05-26 09:18:02Z trygvis $
 * @description Validate consistency between Grails (application.properties) and Maven (pom.xml) settings.
 * @goal validate
 * @phase validate
 * @since 0.1
 */
public class MvnValidateMojo extends AbstractGrailsMojo {

    /**
     * The artifact id of the project.
     *
     * @parameter expression="${project.artifactId}"
     * @required
     * @readonly
     */
    private String artifactId;

    /**
     * The version id of the project.
     *
     * @parameter expression="${project.version}"
     * @required
     * @readonly
     */
    private String version;

    public void execute() throws MojoExecutionException, MojoFailureException {
        try {
            GrailsProject grailsProject = getGrailsServices().readProjectDescriptor();

            if (!artifactId.equals(grailsProject.getAppName())) {
                throw new MojoFailureException("app.name [" + grailsProject.getAppName() + "] in " +
                    "application.properties is different of the artifactId [" + artifactId + "] in the pom.xml");
            }

            String pomVersion = version.trim();
            String grailsVersion = grailsProject.getAppVersion().trim();

            if (!grailsVersion.equals(pomVersion)) {
                throw new MojoFailureException("app.version [" + grailsVersion + "] in " +
                    "application.properties is different of the version [" + pomVersion + "] in the pom.xml");
            }
        } catch (IOException e) {
            throw new MojoExecutionException("Unable to load grails project descriptor.", e);
        }
    }
}
