/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.octo.mtg.plugin;

import org.apache.maven.artifact.handler.ArtifactHandler;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.project.MavenProject;

import java.io.File;

/**
 * Creates a WAR archive and register it in maven.
 *
 * @author <a href="mailto:aheritier@gmail.com">Arnaud HERITIER</a>
 * @version $Id: MvnWarMojo.java 457 2008-05-23 10:57:27Z trygvis $
 * @description Creates a WAR archive and register it in maven.
 * @goal maven-war
 * @phase package
 * @since 0.1
 */
public class MvnWarMojo extends AbstractGrailsMojo {

    /**
     * The maven project.
     *
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    private MavenProject project;

    /**
     * The artifact handler.
     *
     * @parameter expression="${component.org.apache.maven.artifact.handler.ArtifactHandler#grails-app}"
     * @required
     * @readonly
     */
    protected ArtifactHandler artifactHandler;

    /**
     * Executes the MvnWarMojo on the current project.
     *
     * @throws MojoExecutionException if an error occured while building the webapp
     */
    public void execute() throws MojoExecutionException, MojoFailureException {
        // launch grails
        getGrailsServices().launchGrails(grailsHome, env, "war");
        String warFileName = getGrailsDescriptor().getAppName() + "-" + getGrailsDescriptor().getAppVersion() + ".war";
        File warGeneratedByGrails = new File(getBasedir(), warFileName);
        File buildDir = new File(project.getBuild().getDirectory());
        buildDir.mkdirs();
        File mavenWarFile = new File(buildDir, project.getBuild().getFinalName() + ".war");
        mavenWarFile.delete();
        boolean result = warGeneratedByGrails.renameTo(mavenWarFile);
        if (!result)
            throw new MojoExecutionException("Unable to copy the war in the target directory");
        project.getArtifact().setFile(mavenWarFile);
        project.getArtifact().setArtifactHandler(artifactHandler);
    }
}
